@@ -146,9 +146,7 @@ mcdb_findtagnext(struct mcdb * const restrict m,
                 m->kpos = m->hpos;
             khash= *(uint32_t *)ptr; /* m->khash stored bigendian */
             vpos = uint32_strunpack_bigendian_aligned_macro(ptr+4);
-            ptr  = mptr + vpos;
-            __builtin_prefetch((char *)ptr, 0, PLASMA_ATTR_MM_HINT_T2);
-            if (__builtin_expect((!vpos), 0))
+            if (!vpos)
                 break;
             ++m->loop;
             if (khash == m->khash) {
@@ -171,8 +169,7 @@ mcdb_findtagnext(struct mcdb * const restrict m,
             khash   = *(uint32_t *)ptr; /* m->khash stored bigendian */
             m->klen = uint32_strunpack_bigendian_aligned_macro(ptr+4);
             vpos    = uint64_strunpack_bigendian_aligned_macro(ptr+8);
-            __builtin_prefetch((char *)mptr+vpos+4, 0, PLASMA_ATTR_MM_HINT_T2);
-            if (__builtin_expect((!vpos), 0))
+            if (!vpos)
                 break;
             ++m->loop;
             if (khash == m->khash && m->klen == klen+(tagc!=0)) {
@@ -293,11 +290,13 @@ mcdb_iter_init(struct mcdb_iter * const restrict iter,
  */
 
 
-static void  inline
-mcdb_mmap_unmap(struct mcdb_mmap * const restrict map)
-  __attribute_nonnull__;
+__attribute_nonnull__
+inline
+static void
+mcdb_mmap_unmap(struct mcdb_mmap * const restrict map);
 
-static void  inline
+inline
+static void
 mcdb_mmap_unmap(struct mcdb_mmap * const restrict map)
 {
     if (map->ptr)
@@ -320,7 +319,11 @@ mcdb_mmap_init(struct mcdb_mmap * const restrict map, int fd)
     if (st.st_size > (off_t)SIZE_MAX) return (errno = EFBIG, false);
   #endif
     x = mmap(0, (size_t)st.st_size, PROT_READ, MAP_SHARED, fd, 0);
-    if (x == MAP_FAILED) return false;             /*(touch page w/ mcdb hdr)*/
+    if (__builtin_expect( (x == MAP_FAILED), 0)) {
+        if (errno == EINVAL)
+            x = mmap(0, (size_t)st.st_size, PROT_READ, MAP_PRIVATE, fd, 0);
+        if (x == MAP_FAILED) return false;
+    } /*(touch page w/ mcdb hdr)*/
     __builtin_prefetch((char *)x, 0, PLASMA_ATTR_MM_HINT_T0);
   #if 0 /* disable; does not appear to improve performance */
     /*(peformance hit when hitting an uncached mcdb on my 32-bit Pentium-M)*/
@@ -469,8 +472,10 @@ mcdb_mmap_create(struct mcdb_mmap * restrict map,
     size_t flen;
     const int allocated = (map != NULL);
 
+  #if !__has_attribute(nonnull)
     if (fn_malloc == NULL)
         return NULL;
+  #endif
     if (map == NULL && (map = fn_malloc(sizeof(struct mcdb_mmap))) == NULL)
         return NULL;
     /* initialize */
