@@ -81,9 +81,11 @@ struct mcdb_input {
  */
 
 __attribute_noinline__
+__attribute_nonnull__
+__attribute_warn_unused_result__
 static ssize_t
-mcdb_bufread_fd (struct mcdb_input * const restrict b)
-  __attribute_nonnull__  __attribute_warn_unused_result__;
+mcdb_bufread_fd (struct mcdb_input * const restrict b);
+
 static ssize_t
 mcdb_bufread_fd (struct mcdb_input * const restrict b)
 {
@@ -102,9 +104,11 @@ mcdb_bufread_fd (struct mcdb_input * const restrict b)
 
 /* (separate routine from mcdb_bufread_preamble for less frequent code path) */
 __attribute_noinline__
+__attribute_nonnull__
+__attribute_warn_unused_result__
 static ssize_t
-mcdb_bufread_preamble_fill (struct mcdb_input * const restrict b)
-  __attribute_nonnull__  __attribute_warn_unused_result__;
+mcdb_bufread_preamble_fill (struct mcdb_input * const restrict b);
+
 static ssize_t
 mcdb_bufread_preamble_fill (struct mcdb_input * const restrict b)
 {
@@ -119,10 +123,12 @@ mcdb_bufread_preamble_fill (struct mcdb_input * const restrict b)
     return r;  /* >= 0 is success; -1 is read error */
 }
 
+__attribute_nonnull__
+__attribute_warn_unused_result__
 static bool
 mcdb_bufread_number (struct mcdb_input * const restrict b,
-                     size_t * const restrict rv)
-  __attribute_nonnull__  __attribute_warn_unused_result__;
+                     size_t * const restrict rv);
+
 static bool
 mcdb_bufread_number (struct mcdb_input * const restrict b,
                      size_t * const restrict rv)
@@ -147,11 +153,13 @@ mcdb_bufread_number (struct mcdb_input * const restrict b,
     return false; /*error: no digits or too large; not bothering to set ERANGE*/
 }
 
+__attribute_nonnull__
+__attribute_warn_unused_result__
 static int
 mcdb_bufread_preamble (struct mcdb_input * const restrict b,
                        size_t * const restrict klen,
-                       size_t * const restrict dlen)
-  __attribute_nonnull__  __attribute_warn_unused_result__;
+                       size_t * const restrict dlen);
+
 static int
 mcdb_bufread_preamble (struct mcdb_input * const restrict b,
                        size_t * const restrict klen,
@@ -174,12 +182,14 @@ mcdb_bufread_preamble (struct mcdb_input * const restrict b,
             : MCDB_ERROR_READFORMAT;           /* -1  error read format  */
 }
 
+__attribute_nonnull__
+__attribute_warn_unused_result__
 static bool
 mcdb_bufread_str (struct mcdb_input * const restrict b, size_t len,
                   struct mcdb_make * const restrict m,
                   void (* const fn_addbuf)(struct mcdb_make * restrict,
-                                           const char * restrict, size_t))
-  __attribute_nonnull__  __attribute_warn_unused_result__;
+                                           const char * restrict, size_t));
+
 static bool
 mcdb_bufread_str (struct mcdb_input * const restrict b, size_t len,
                   struct mcdb_make * const restrict m,
@@ -197,9 +207,11 @@ mcdb_bufread_str (struct mcdb_input * const restrict b, size_t len,
 }
 
 __attribute_noinline__
+__attribute_nonnull__
+__attribute_warn_unused_result__
 static bool
-mcdb_bufread_xchars (struct mcdb_input * const restrict b, const size_t len)
-  __attribute_nonnull__  __attribute_warn_unused_result__;
+mcdb_bufread_xchars (struct mcdb_input * const restrict b, const size_t len);
+
 static bool
 mcdb_bufread_xchars (struct mcdb_input * const restrict b, const size_t len)
 {
@@ -209,11 +221,13 @@ mcdb_bufread_xchars (struct mcdb_input * const restrict b, const size_t len)
 }
 
 __attribute_noinline__
+__attribute_nonnull__
+__attribute_warn_unused_result__
 static bool
 mcdb_bufread_rec (struct mcdb_make * const restrict m,
                   const size_t klen, const size_t dlen,
-                  struct mcdb_input * const restrict b)
-  __attribute_nonnull__  __attribute_warn_unused_result__;
+                  struct mcdb_input * const restrict b);
+
 static bool
 mcdb_bufread_rec (struct mcdb_make * const restrict m,
                   const size_t klen, const size_t dlen,
@@ -342,7 +356,7 @@ mcdb_makefmt_fileintofile (const char * const restrict infile,
        #if !defined(_LP64) && !defined(__LP64__)
         || (st.st_size > (off_t)SIZE_MAX ? (errno = EFBIG) : 0)
        #endif
-        || ((x = mmap(0, (size_t)st.st_size, PROT_READ, MAP_SHARED, fd, 0))
+        || ((x = mmap(0, (size_t)st.st_size, PROT_READ, MAP_PRIVATE, fd, 0))
             == MAP_FAILED))
         errsave = errno;
 
