@@ -39,20 +39,24 @@ extern "C" {
  * Note: caller of mcdb_makefmt_fdintofd() should choose whether or not to then
  * call fsync() or fdatasync().  See notes in mcdb_make.c:mcdb_mmap_commit() */
 
-int
+__attribute_nonnull__
+__attribute_warn_unused_result__
+EXPORT extern int
 mcdb_makefmt_fdintofd (int, char * restrict, size_t,
-                       int, void * (*)(size_t), void (*)(void *))
-  __attribute_nonnull__  __attribute_warn_unused_result__;
+                       int, void * (*)(size_t), void (*)(void *));
 
-int
+__attribute_nonnull__
+__attribute_warn_unused_result__
+EXPORT extern int
 mcdb_makefmt_fdintofile (const int, char * restrict, size_t,
                          const char * restrict,
-                         void * (*)(size_t), void (*)(void *))
-  __attribute_nonnull__  __attribute_warn_unused_result__;
-int
+                         void * (*)(size_t), void (*)(void *));
+
+__attribute_nonnull__
+__attribute_warn_unused_result__
+EXPORT extern int
 mcdb_makefmt_fileintofile (const char * restrict, const char * restrict,
-                           void * (*)(size_t), void (*)(void *))
-  __attribute_nonnull__  __attribute_warn_unused_result__;
+                           void * (*)(size_t), void (*)(void *));
 
 #ifdef __cplusplus
 }
