@@ -43,12 +43,12 @@
 #include <sys/mman.h>
 #include <sys/stat.h>
 #include <fcntl.h>   /* open(), O_RDONLY */
-#include <stdio.h>   /* printf(), IOV_MAX */
+#include <stdio.h>   /* printf() */
 #include <stdlib.h>  /* malloc(), free(), EXIT_SUCCESS */
 #include <string.h>  /* strlen() */
 #include <unistd.h>  /* STDIN_FILENO, STDOUT_FILENO */
 #include <sys/uio.h> /* writev() */
-#include <limits.h>  /* SSIZE_MAX */
+#include <limits.h>  /* IOV_MAX, SSIZE_MAX */
 
 /*(posix_madvise, defines not provided in Solaris 10, even w/ __EXTENSIONS__)*/
 #if (defined(__sun) || defined(__hpux)) && !defined(POSIX_MADV_NORMAL)
@@ -62,11 +62,13 @@ extern int madvise(caddr_t, size_t, int);
 #endif
 
 /* code to hint to release memory pages every 32 MB (1u << 25) */
+__attribute_nonnull__
+__attribute_warn_unused_result__
 static unsigned char *
-mcdb_madv_initmark(unsigned char * const ptr, const uintptr_t sz, size_t offset)
-  __attribute_nonnull__  __attribute_warn_unused_result__;
+mcdb_madv_initmark(unsigned char * const ptr,const uintptr_t sz,size_t offset);
+
 static unsigned char *
-mcdb_madv_initmark(unsigned char * const ptr, const uintptr_t sz, size_t offset)
+mcdb_madv_initmark(unsigned char * const ptr,const uintptr_t sz,size_t offset)
 {
     if (offset != 0) {
         /* round up if non-zero to avoid calling dontneed on mcdb header page */
@@ -88,9 +90,11 @@ mcdb_madv_initmark(unsigned char * const ptr, const uintptr_t sz, size_t offset)
     }                                                                          \
   } while (0)
 
+__attribute_nonnull__
+__attribute_warn_unused_result__
 static bool
-writev_loop(const int fd, struct iovec * restrict iov, int iovcnt, ssize_t sz)
-  __attribute_nonnull__  __attribute_warn_unused_result__;
+writev_loop(const int fd, struct iovec * restrict iov, int iovcnt, ssize_t sz);
+
 static bool
 writev_loop(const int fd, struct iovec * restrict iov, int iovcnt, ssize_t sz)
 {
@@ -117,9 +121,11 @@ writev_loop(const int fd, struct iovec * restrict iov, int iovcnt, ssize_t sz)
 }
 
 /* read and dump data section of mcdb */
+__attribute_nonnull__
+__attribute_warn_unused_result__
 static int
-mcdbctl_dump(struct mcdb * const restrict m)
-  __attribute_nonnull__  __attribute_warn_unused_result__;
+mcdbctl_dump(struct mcdb * const restrict m);
+
 static int
 mcdbctl_dump(struct mcdb * const restrict m)
 {
@@ -129,9 +135,9 @@ mcdbctl_dump(struct mcdb * const restrict m)
     unsigned char *mark = mcdb_madv_initmark(m->map->ptr, m->map->size, 0);
     int    iovcnt = 0;
     size_t iovlen = 0;
-    size_t buflen = 0;
-    enum { MCDB_IOVNUM = IOV_MAX };/* assert(IOV_MAX >= 7) */
-    struct iovec iov[MCDB_IOVNUM]; /* each db entry uses 7 iovecs */
+    size_t buflen = 0;             /* _XOPEN_IOV_MAX minimum is 16 */
+    enum { MCDB_IOVNUM = IOV_MAX };/* assert(IOV_MAX >= 9) */
+    struct iovec iov[MCDB_IOVNUM]; /* each db entry uses 9 iovecs */
     char buf[(MCDB_IOVNUM * 3)];   /* each db entry might use (2) * 10 chars */
       /* oversized buffer since all num strings must add up to less than max */
 
@@ -145,7 +151,7 @@ mcdbctl_dump(struct mcdb * const restrict m)
 
         /* avoid printf("%.*s\n",...) due to mcdb arbitrary binary data */
         /* klen, dlen each limited to (2GB - 8); space for extra tokens exists*/
-        if (iovlen + klen + 5 > SSIZE_MAX || iovcnt + 7 >= MCDB_IOVNUM) {
+        if (iovlen + klen + 5 > SSIZE_MAX || iovcnt + 8 >= MCDB_IOVNUM) {
             if (!writev_loop(STDOUT_FILENO, iov, iovcnt, (ssize_t)iovlen))
                 return MCDB_ERROR_WRITE;
             iovcnt = 0;
@@ -213,9 +219,11 @@ mcdbctl_dump(struct mcdb * const restrict m)
 }
 
 /* Note: mcdbctl_stats() is equivalent test to pass/fail of djb cdbtest */
+__attribute_nonnull__
+__attribute_warn_unused_result__
 static int
-mcdbctl_stats(struct mcdb * const restrict m)
-  __attribute_nonnull__  __attribute_warn_unused_result__;
+mcdbctl_stats(struct mcdb * const restrict m);
+
 static int
 mcdbctl_stats(struct mcdb * const restrict m)
 {
@@ -256,10 +264,12 @@ mcdbctl_stats(struct mcdb * const restrict m)
     return EXIT_SUCCESS;
 }
 
+__attribute_nonnull__
+__attribute_warn_unused_result__
 static int
 mcdbctl_getseq(struct mcdb * const restrict m,
-               const char * const restrict key, unsigned long seq)
-  __attribute_nonnull__  __attribute_warn_unused_result__;
+               const char * const restrict key, unsigned long seq);
+
 static int
 mcdbctl_getseq(struct mcdb * const restrict m,
                const char * const restrict key, unsigned long seq)
@@ -284,10 +294,12 @@ mcdbctl_getseq(struct mcdb * const restrict m,
     return EXIT_FAILURE;
 }
 
+__attribute_nonnull__
+__attribute_warn_unused_result__
 static int
 mcdbctl_getall(struct mcdb * const restrict m,
-               const char * const restrict key)
-  __attribute_nonnull__  __attribute_warn_unused_result__;
+               const char * const restrict key);
+
 static int
 mcdbctl_getall(struct mcdb * const restrict m,
                const char * const restrict key)
@@ -309,9 +321,11 @@ mcdbctl_getall(struct mcdb * const restrict m,
     return EXIT_FAILURE;
 }
 
+__attribute_nonnull__
+__attribute_warn_unused_result__
 static int
-mcdbctl_query(const int argc, char ** restrict argv)
-  __attribute_nonnull__  __attribute_warn_unused_result__;
+mcdbctl_query(const int argc, char ** restrict argv);
+
 static int
 mcdbctl_query(const int argc, char ** restrict argv)
 {
@@ -375,6 +389,7 @@ mcdbctl_query(const int argc, char ** restrict argv)
       case MCDBCTL_STATS:
         rv = mcdbctl_stats(&m);
         break;
+      /* coverity[dead_error_begin: FALSE] */
       default: /* should not happen */
         rv = MCDB_ERROR_USAGE;
         break;
@@ -384,9 +399,11 @@ mcdbctl_query(const int argc, char ** restrict argv)
     return rv;
 }
 
+__attribute_nonnull__
+__attribute_warn_unused_result__
 static int
-mcdbctl_make(const int argc __attribute_unused__, char ** const restrict argv)
-  __attribute_nonnull__  __attribute_warn_unused_result__;
+mcdbctl_make(const int argc __attribute_unused__, char ** const restrict argv);
+
 static int
 mcdbctl_make(const int argc __attribute_unused__, char ** const restrict argv)
 {
@@ -405,9 +422,11 @@ mcdbctl_make(const int argc __attribute_unused__, char ** const restrict argv)
     return rv;
 }
 
+__attribute_nonnull__
+__attribute_warn_unused_result__
 static int
-mcdbctl_has_unique_keys(struct mcdb * const restrict m)
-  __attribute_nonnull__  __attribute_warn_unused_result__;
+mcdbctl_has_unique_keys(struct mcdb * const restrict m);
+
 static int
 mcdbctl_has_unique_keys(struct mcdb * const restrict m)
 {
@@ -436,9 +455,11 @@ mcdbctl_has_unique_keys(struct mcdb * const restrict m)
     return true;  /*keys are unique in mcdb*/
 }
 
+__attribute_nonnull__
+__attribute_warn_unused_result__
 static int
-mcdbctl_make_unique_keys(struct mcdb * const restrict m, const bool first)
-  __attribute_nonnull__  __attribute_warn_unused_result__;
+mcdbctl_make_unique_keys(struct mcdb * const restrict m, const bool first);
+
 static int
 mcdbctl_make_unique_keys(struct mcdb * const restrict m, const bool first)
 {
@@ -498,9 +519,11 @@ mcdbctl_make_unique_keys(struct mcdb * const restrict m, const bool first)
     return rv;
 }
 
+__attribute_nonnull__
+__attribute_warn_unused_result__
 static int
-mcdbctl_uniq(const int argc, char ** const restrict argv)
-  __attribute_nonnull__  __attribute_warn_unused_result__;
+mcdbctl_uniq(const int argc, char ** const restrict argv);
+
 static int
 mcdbctl_uniq(const int argc, char ** const restrict argv)
 {
