@@ -228,6 +228,15 @@
 #endif
 #endif
 
+#ifndef __attribute_returns_nonnull__
+#if __has_attribute(returns_nonnull) \
+ || __GNUC_PREREQ(4,9)
+#define __attribute_returns_nonnull__  __attribute__((__returns_nonnull__))
+#else
+#define __attribute_returns_nonnull__
+#endif
+#endif
+
 #ifndef __attribute_malloc__
 #if __has_attribute(malloc) \
  || __GNUC_PREREQ(2,96) \
@@ -244,15 +253,33 @@
 #endif
 #endif
 
+#ifndef __attribute_alloc_align__
+#if __has_attribute(alloc_align) \
+ || __GNUC_PREREQ(4,9)
+#define __attribute_alloc_align__(pos)  __attribute__((__alloc_align__ pos))
+#else
+#define __attribute_alloc_align__(pos)
+#endif
+#endif
+
 #ifndef __attribute_alloc_size__
 #if __has_attribute(alloc_size) \
  || __GNUC_PREREQ(4,3)
-#define __attribute_alloc_size__(pos)  __attribute__((__alloc_size__(pos)))
+#define __attribute_alloc_size__(pos)  __attribute__((__alloc_size__ pos))
 #else
 #define __attribute_alloc_size__(pos)
 #endif
 #endif
 
+#ifndef __attribute_assume_aligned__
+#if __has_attribute(assume_aligned) \
+ || __GNUC_PREREQ(4,9)
+#define __attribute_assume_aligned__(x)  __attribute__((__assume_aligned__ x))
+#else
+#define __attribute_assume_aligned__(x)
+#endif
+#endif
+
 #ifndef __attribute_pure__
 #if __has_attribute(pure) \
  || __GNUC_PREREQ(2,96) \
@@ -291,6 +318,15 @@
  * so might be used in addition to portable code marked with attribute pure,
  * provided requirements are met for pragma no_side_effect or isolated_call. */
 
+#ifndef __attribute_leaf__
+#if (__has_attribute(leaf) \
+ || __GNUC_PREREQ(4,6)) && !defined(_LIBC)
+#define __attribute_leaf__  __attribute__((__leaf__))
+#else
+#define __attribute_leaf__
+#endif
+#endif
+
 #ifndef __attribute_hot__
 #if __has_attribute(hot) \
  || __GNUC_PREREQ(4,3)
@@ -532,9 +568,15 @@
 
 #if __has_builtin(__builtin_constant_p) \
  || __GNUC_PREREQ(3,1)/*(check major,minor ver; actually supported in 3.0.1)*/\
- || defined(__IBMC__) || defined(__IBMCPP__) \
+ || defined(__IBMC__) || (defined(__IBMCPP__) && __IBMCPP__ >= 1310) \
  || (defined(__SUNPRO_C)  && __SUNPRO_C  >= 0x5100) /* Sun Studio 12.1 C   */
 #define plasma_attr_has_builtin_constant_p
+/* IBM xlC (C++) compiler has a bug in 32-bit compilation on constant 8-byte
+ * value via initialization assignment (and not simply integer literal)
+ * which is fixed in XL C/C++ 12.1 March 2014 PTF and later (XL C/C++ 13.1)
+ * [PMR 77049,7TD,000] IBM notes that __builtin_constant_p() is not officially
+ * documented and was originally intended for compiling Linux headers with
+ * XL C/C++ for Linux */
 #else
 #ifndef __builtin_constant_p
 #define __builtin_constant_p(x) 0
