@@ -98,7 +98,7 @@ PLASMA_ATTR_Pragma_once
   #define __BIG_ENDIAN__ 1
   #endif
 #elif defined(__FreeBSD__) || defined(__NetBSD__) \
-   || defined(__OpenBSD__) || defined(__DragonflyBSD__)
+   || defined(__OpenBSD__) || defined(__DragonFly__)
   #include <machine/endian.h>
   #if _BYTE_ORDER == _LITTLE_ENDIAN
   #define __LITTLE_ENDIAN__ 1
@@ -134,6 +134,14 @@ PLASMA_ATTR_Pragma_once
 #error "both __BIG_ENDIAN__ and __LITTLE_ENDIAN__ defined"
 #endif
 
+#ifdef __LITTLE_ENDIAN__
+  #define PLASMA_ENDIAN_LITTLE  1
+  #define PLASMA_ENDIAN_BIG     0
+#else /* __BIG_ENDIAN__ */
+  #define PLASMA_ENDIAN_LITTLE  0
+  #define PLASMA_ENDIAN_BIG     1
+#endif
+
 /* gcc 4.6+ http://gcc.gnu.org/onlinedocs/cpp/Common-Predefined-Macros.html
  * http://publib.boulder.ibm.com/infocenter/macxhelp/v6v81/index.jsp?topic=%2Fcom.ibm.vacpp6m.doc%2Fcompiler%2Fref%2Frumacros.htm
  */
@@ -158,7 +166,7 @@ PLASMA_ATTR_Pragma_once
 #define plasma_endian_swap32p(x)  __bswap_32(*(x))
 #define plasma_endian_swap64p(x)  __bswap_64(*(x))
 
-#elif defined(__FreeBSD__) || defined(__NetBSD__) || defined(__DragonflyBSD__)
+#elif defined(__FreeBSD__) || defined(__NetBSD__) || defined(__DragonFly__)
 
 #include <machine/endian.h>
 /* http://fxr.watson.org/fxr/source/sys/endian.h */
@@ -290,7 +298,7 @@ PLASMA_ATTR_Pragma_once
 
 /* AIX xlc byte swapping intrinsics take pointer arguments; use in inline func
  * https://publib.boulder.ibm.com/infocenter/comphelp/v8v101/index.jsp?topic=%2Fcom.ibm.xlcpp8a.doc%2Fcompiler%2Fref%2Fbif_int.htm
- * (assembly not provided here for GCC < 4.3 (without __builtin_bswap_*()))
+ * (assembly not provided here for GCC < 4.3 (without __builtin_bswap*()))
  * http://cr.illumos.org/~webrev/skiselkov/edonr/usr/src/common/crypto/edonr/edonr_byteorder.h.html */
 
   #define plasma_endian_swap16p_funcmacro(x)  __load2r(x)
@@ -362,6 +370,26 @@ PLASMA_ATTR_Pragma_once
 #endif
 
 
+#ifdef __clang__
+
+  #if __has_builtin(__builtin_bswap16)
+  #undef  plasma_endian_swap16_funcmacro
+  #define plasma_endian_swap16_funcmacro(x)   __builtin_bswap16(x)
+  #endif
+
+  #if __has_builtin(__builtin_bswap32)
+  #undef  plasma_endian_swap32_funcmacro
+  #define plasma_endian_swap32_funcmacro(x)   __builtin_bswap32(x)
+  #endif
+
+  #if __has_builtin(__builtin_bswap64)
+  #undef  plasma_endian_swap64_funcmacro
+  #define plasma_endian_swap64_funcmacro(x)   __builtin_bswap64(x)
+  #endif
+
+#endif
+
+
 /* (plasma_endian_*_const macros require x to be unsigned type of proper size)*/
 
 #define plasma_endian_swap16_const(x) \
@@ -444,11 +472,12 @@ plasma_endian_swap16_func (const uint16_t x);
 
 #ifndef plasma_endian_swap16p_funcmacro
 #define plasma_endian_swap16p_func plasma_endian_swap16p_func
+__attribute_nonnull__
+__attribute_nothrow__
 __attribute_pure__
 PLASMA_ENDIAN_C99INLINE
 uint16_t
-plasma_endian_swap16p_func (const uint16_t * const restrict x)
-  __attribute_nonnull__  __attribute_nothrow__;
+plasma_endian_swap16p_func (const uint16_t * const restrict x);
 PLASMA_ATTR_Pragma_no_side_effect(plasma_endian_swap16p_func)
 #endif
 
@@ -495,11 +524,12 @@ plasma_endian_swap32_func (const uint32_t x);
 
 #ifndef plasma_endian_swap32p_funcmacro
 #define plasma_endian_swap32p_func plasma_endian_swap32p_func
+__attribute_nonnull__
+__attribute_nothrow__
 __attribute_pure__
 PLASMA_ENDIAN_C99INLINE
 uint32_t
-plasma_endian_swap32p_func (const uint32_t * const restrict x)
-  __attribute_nonnull__  __attribute_nothrow__;
+plasma_endian_swap32p_func (const uint32_t * const restrict x);
 PLASMA_ATTR_Pragma_no_side_effect(plasma_endian_swap32p_func)
 #endif
 
@@ -546,11 +576,12 @@ plasma_endian_swap64_func (const uint64_t x);
 
 #ifndef plasma_endian_swap64p_funcmacro
 #define plasma_endian_swap64p_func plasma_endian_swap64p_func
+__attribute_nonnull__
+__attribute_nothrow__
 __attribute_pure__
 PLASMA_ENDIAN_C99INLINE
 uint64_t
-plasma_endian_swap64p_func (const uint64_t * const restrict x)
-  __attribute_nonnull__  __attribute_nothrow__;
+plasma_endian_swap64p_func (const uint64_t * const restrict x);
 PLASMA_ATTR_Pragma_no_side_effect(plasma_endian_swap64p_func)
 #endif
 
