@@ -50,7 +50,8 @@
 #endif
 #endif
 #ifdef PLASMA_FEATURE_ENABLE_BSD_SOURCE_TO_DARWIN_C_SOURCE
-#if defined(_BSD_SOURCE) && !defined(_DARWIN_C_SOURCE)
+#if (defined(_BSD_SOURCE) || defined(_DEFAULT_SOURCE)) \
+ && !defined(_DARWIN_C_SOURCE)
 #define _DARWIN_C_SOURCE
 #endif
 #endif
@@ -163,7 +164,7 @@
   #endif
 #elif (defined(__APPLE__) && defined(__MACH__)) \
    || defined(__FreeBSD__) || defined(__NetBSD__) \
-   || defined(__OpenBSD__) || defined(__DragonflyBSD__)
+   || defined(__OpenBSD__) || defined(__DragonFly__)
   /* *BSD, MacOSX (Darwin) use 64-bit off_t in both 32-bit and 64-bit compile
    * (BSD 4.4 and later) */
   #ifdef PLASMA_FEATURE_ENABLE_LARGEFILE64 /* largefile64 types, interfaces */
@@ -191,6 +192,7 @@
  * Feature Macros must be defined prior to including any headers to take effect.
  * _POSIX_C_SOURCE
  * _XOPEN_SOURCE
+ * _DEFAULT_SOURCE
  * _SVID_SOURCE
  * _BSD_SOURCE
  * ... and many more  (XXX: add publicly available links to standards)
@@ -207,7 +209,7 @@
 #include <standards.h>
 #elif (defined(__APPLE__) && defined(__MACH__))  /* man -s 5 compat */ \
    || defined(__FreeBSD__) || defined(__NetBSD__) \
-   || defined(__OpenBSD__) || defined(__DragonflyBSD__)
+   || defined(__OpenBSD__) || defined(__DragonFly__)
 #include <sys/cdefs.h>
 #elif defined(__hpux)
 /*#include <XXX>*/
