@@ -34,6 +34,7 @@ PLASMA_ATTR_Pragma_once
 
 #if defined(__APPLE__) && defined(__MACH__)
 #include <libkern/OSAtomic.h>
+#include <sched.h>
 #endif
 
 #ifndef PLASMA_SPIN_C99INLINE
@@ -213,9 +214,10 @@ PLASMA_ATTR_Pragma_once
   #include <poll.h>    /* might also need _XOPEN_SOURCE=500 or better on _AIX */
   #if defined(_POSIX_PRIORITY_SCHEDULING) && (_POSIX_PRIORITY_SCHEDULING-0)!= -1
   #include <sched.h>
-  #define plasma_spin_yield() do {if (sched_yield()!=0) poll(NULL,0,1);}while(0)
+  #define plasma_spin_yield() \
+    do {if (sched_yield()!=0) (void)poll(NULL, 0, 1); } while(0)
   #else
-  #define plasma_spin_yield() poll(NULL, 0, 1)
+  #define plasma_spin_yield() (void)poll(NULL, 0, 1)
   #endif
 #endif
 
@@ -228,11 +230,12 @@ PLASMA_ATTR_Pragma_once
   #include <TargetConditionals.h>
   #if TARGET_OS_MAC
     #include <mach/thread_switch.h>
+    #include <sched.h>
     #undef  plasma_spin_yield
     #define plasma_spin_yield() \
     do {if (thread_switch(THREAD_NULL,SWITCH_OPTION_DEPRESS,1) != KERN_SUCCESS \
             && sched_yield() != 0) \
-            poll(NULL, 0, 1); \
+            (void)poll(NULL, 0, 1); \
     } while (0) /* (untested!) */
   #endif
 #endif
@@ -322,7 +325,7 @@ struct plasma_spin_lock_t {
 /* default spin lock macro implementation */
 #ifndef PLASMA_SPIN_LOCK_INITIALIZER
 
-#ifdef __STDC_C99
+#if (defined(__STDC_VERSION__) && __STDC_VERSION__-0 >= 199901L) /* C99 */
 #define PLASMA_SPIN_LOCK_INITIALIZER { .lck = PLASMA_ATOMIC_LOCK_INITIALIZER, \
                                        .udata32 = 0, \
                                        .udata64 = 0 }
@@ -350,15 +353,15 @@ struct plasma_spin_lock_t {
 
 #ifndef plasma_spin_lock_acquire_spinloop
 /*(plasma_spin_lock_acquire_spinloop() always returns true)*/
+__attribute_nonnull__
 bool
-plasma_spin_lock_acquire_spinloop (plasma_spin_lock_t * const spin)
-  __attribute_nonnull__;
+plasma_spin_lock_acquire_spinloop (plasma_spin_lock_t * const spin);
 #endif
 
+__attribute_nonnull__
 bool
 plasma_spin_lock_acquire_spindecay (plasma_spin_lock_t * const spin,
-                                    int pause1, int pause32, int yield)
-  __attribute_nonnull__;
+                                    int pause1, int pause32, int yield);
 
 
 /* plasma_spin_tktlock_*()  ticket lock
@@ -388,17 +391,17 @@ struct plasma_spin_tktlock_t {
 #define PLASMA_SPIN_TKTLOCK_MASK(x)      ((x) &  PLASMA_SPIN_TKTLOCK_TKTMAX)
 #define PLASMA_SPIN_TKTLOCK_SHIFT(x)     ((x) >> 16)
 
-#ifdef __STDC_C99
+#if (defined(__STDC_VERSION__) && __STDC_VERSION__-0 >= 199901L) /* C99 */
 #define PLASMA_SPIN_TKTLOCK_INITIALIZER {.lck.u = 0, .udata32 = 0, .udata64 = 0}
 #else
 #define PLASMA_SPIN_TKTLOCK_INITIALIZER { { 0 }, 0, 0 }
 #endif
 #define plasma_spin_tktlock_init(t) ((t)->lck.u=0,(t)->udata32=0,(t)->udata64=0)
 
+__attribute_nonnull__
 PLASMA_SPIN_C99INLINE
 bool
-plasma_spin_tktlock_is_free (const plasma_spin_tktlock_t * const restrict spin)
-  __attribute_nonnull__;
+plasma_spin_tktlock_is_free (const plasma_spin_tktlock_t * const restrict spin);
 #ifdef PLASMA_SPIN_C99INLINE_FUNCS
 PLASMA_SPIN_C99INLINE
 bool
@@ -411,16 +414,16 @@ plasma_spin_tktlock_is_free (const plasma_spin_tktlock_t * const restrict spin)
 
 /*(plasma_spin_tktlock_acquire_spinloop() always returns true)*/
 __attribute_noinline__
+__attribute_nonnull__
 bool
 plasma_spin_tktlock_acquire_spinloop (plasma_spin_tktlock_t *
-                                        const restrict spin, uint32_t tkt)
-  __attribute_nonnull__;
+                                        const restrict spin, uint32_t tkt);
 
 /*(plasma_spin_tktlock_acquire() always returns true)*/
+__attribute_nonnull__
 PLASMA_SPIN_C99INLINE
 bool
-plasma_spin_tktlock_acquire (plasma_spin_tktlock_t * const restrict spin)
-  __attribute_nonnull__;
+plasma_spin_tktlock_acquire (plasma_spin_tktlock_t * const restrict spin);
 #ifdef PLASMA_SPIN_C99INLINE_FUNCS
 PLASMA_SPIN_C99INLINE
 bool
@@ -441,10 +444,10 @@ plasma_spin_tktlock_acquire (plasma_spin_tktlock_t * const restrict spin)
 }
 #endif
 
+__attribute_nonnull__
 PLASMA_SPIN_C99INLINE
 void
-plasma_spin_tktlock_release (plasma_spin_tktlock_t * const restrict spin)
-  __attribute_nonnull__;
+plasma_spin_tktlock_release (plasma_spin_tktlock_t * const restrict spin);
 #ifdef PLASMA_SPIN_C99INLINE_FUNCS
 PLASMA_SPIN_C99INLINE
 void
@@ -514,7 +517,7 @@ struct plasma_spin_taglock_t {
 #define PLASMA_SPIN_TAGLOCK_UNLOCKVAL(x) ((x) & ~PLASMA_SPIN_TAGLOCK_ORVAL)
 #define PLASMA_SPIN_TAGLOCK_LOCKVAL(x)   ((x) |  PLASMA_SPIN_TAGLOCK_ORVAL)
 
-#ifdef __STDC_C99
+#if (defined(__STDC_VERSION__) && __STDC_VERSION__-0 >= 199901L) /* C99 */
 #define PLASMA_SPIN_TAGLOCK_INITIALIZER { .lck = 0, .tag = 0, .udata64 = 0 }
 #else
 #define PLASMA_SPIN_TAGLOCK_INITIALIZER { 0, 0, 0 }
@@ -534,10 +537,11 @@ struct plasma_spin_taglock_t {
 /* NOTE: plasma_spin_taglock_acquire_try() is *unfair*; avoid under contention
  * (e.g. caller might first check lock using plasma_spin_taglock_is_contended()
  *  or maintain a flag in separate cache line to call acquire vs acquire_try) */
+__attribute_nonnull__
 PLASMA_SPIN_C99INLINE
 bool
-plasma_spin_taglock_acquire_try (plasma_spin_taglock_t * const restrict taglock)
-  __attribute_nonnull__;
+plasma_spin_taglock_acquire_try (plasma_spin_taglock_t *
+                                   const restrict taglock);
 #ifdef PLASMA_SPIN_C99INLINE_FUNCS
 PLASMA_SPIN_C99INLINE
 bool
@@ -570,22 +574,22 @@ plasma_spin_taglock_acquire_try (plasma_spin_taglock_t * const restrict taglock)
 #endif
 
 
+__attribute_nonnull__
 bool
-plasma_spin_taglock_acquire (plasma_spin_taglock_t * const restrict taglock)
-  __attribute_nonnull__;
+plasma_spin_taglock_acquire (plasma_spin_taglock_t * const restrict taglock);
 
 /* NOTE: plasma_spin_taglock_acquire_urgent() is *unfair*
  * (but that is the point); avoid many urgent contenders */
+__attribute_nonnull__
 bool
 plasma_spin_taglock_acquire_urgent (plasma_spin_taglock_t *
-                                      const restrict taglock)
-  __attribute_nonnull__;
+                                      const restrict taglock);
 
 
+__attribute_nonnull__
 PLASMA_SPIN_C99INLINE
 void
-plasma_spin_taglock_release (plasma_spin_taglock_t * const restrict taglock)
-  __attribute_nonnull__;
+plasma_spin_taglock_release (plasma_spin_taglock_t * const restrict taglock);
 #ifdef PLASMA_SPIN_C99INLINE_FUNCS
 PLASMA_SPIN_C99INLINE
 void
