@@ -78,34 +78,34 @@ plasma_test_realloc (void *ptr, size_t size);
 
 
 __attribute_cold__
+__attribute_nonnull__
 __attribute_noinline__
 int
-plasma_test_cond_failure (const char *func, const int line, const char *errstr)
-  __attribute_nonnull__;
+plasma_test_cond_failure (const char *func, const int line, const char *errstr);
 
 
 __attribute_cold__
+__attribute_nonnull__
 __attribute_noinline__
 int
 plasma_test_cond_idx_failure (const char *func, const int line,
-                              const char *errstr, const int loopidx)
-  __attribute_nonnull__;
+                              const char *errstr, const int loopidx);
 
 
 __attribute_cold__
 __attribute_noinline__
+__attribute_nonnull__
 __attribute_noreturn__
 void
 plasma_test_perror_abort (const char *func, const int line,
-                          const char *errstr, int errnum)
-  __attribute_nonnull__;
+                          const char *errstr, int errnum);
 
 
 __attribute_noinline__
+__attribute_nonnull_x__((2))
 void
 plasma_test_nthreads (const int nthr, void *(*thr_func)(void *),
-                      void **thr_args, void **thr_rv)
-  __attribute_nonnull_x__((2));
+                      void **thr_args, void **thr_rv);
 
 
 int
